@@ -1,15 +1,14 @@
 import cv2
-import numpy as np
 
 
 def pendulum_render_fn(img, observation, action):
     height, width, _ = img.shape
     side_length = min(width, height)
-    state = observation.msgs[-1].data
+    state = observation.msgs[-1]
 
     img += 255
     length = 2 * side_length // 9
-    sin_theta, cos_theta = np.sin(state[0]), np.cos(state[0])
+    cos_theta, sin_theta = state[0], state[1]
 
     img = cv2.circle(img, (width // 2, height // 2), side_length // 3, (255, 0, 0), -1)
     img = cv2.circle(img, (width // 2, height // 2), side_length // 12, (192, 192, 192), -1)
